@@ -37,10 +37,11 @@ from calculate.lib.variables.user import LdapHelper
 import pwd
 from calculate.client.client import Client
 
-from calculate.lib.cl_lang import setLocalTranslate
+from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
 
 _ = lambda x: x
 setLocalTranslate('cl_client3', sys.modules[__name__])
+__ = getLazyLocalTranslate(_)
 
 
 class VariableClRemoteHost(Variable):
@@ -106,7 +107,7 @@ class VariableClRemotePw(Variable):
     opt = ["--domain-password"]
 
     def init(self):
-        self.label = _("Domain password")
+        self.label = __("Domain password")
         self.help = _("specify the domain password")
 
     def get(self):
